List of PTMs
============

.. list-table::
   :header-rows: 1
   :widths: 15 15 15 30 25


   * - Canonical
     - Modified
     - Type
     - Full name
     - Links
   * - VAL
     - V3H
     - Hydroxylation
     - 3-Hydroxy-Valine
     - ChemSpider, PubChemIDs
   * - ARG
     - RMN
     - METY
     -
     - omega-N-methylarginine (0)
   * - ARG
     - RSM
     - MS2N
     -
     - symmetric-dimethylarginine (0)
   * - ARG
     - RMS
     - MS2C
     -
     - symmetric-dimethylarginine (+1)
   * - ARG
     - RAM
     - MA2N
     -
     - asymmetric-dimethylarginine (0)

